@@ -5,6 +5,8 @@
 #' @param n sample size (default=800)
 #' @param seed seed number (default=513413)
 #' @param family Outcome type ("gaussian", "binomial", "survival")
+#' @param null Simulate null hypothesis of no treatment effect and no subgruops. Default
+#' is FALSE.
 #' @param ... Any additional parameters, not currently passed through.
 #'
 #' @importFrom stats rbinom rnorm time
@@ -14,7 +16,7 @@
 #' @export
 #'
 
-generate_subgrp_data = function(n=800, seed=513413, family, ...){
+generate_subgrp_data = function(n=800, seed=513413, family, null=FALSE, ...){
 
   # Sample size #
   set.seed(seed)
@@ -34,10 +36,16 @@ generate_subgrp_data = function(n=800, seed=513413, family, ...){
   subgrps = ifelse( X1_cut==1 & X2_cut==0, "[X1+ X2-]", subgrps)
   subgrps = ifelse( X1_cut==1 & X2_cut==1, "[X1+ X2+]", subgrps)
   if (family=="gaussian"){
+    if (!null){
+      trt.effect = A*( 0.65*ifelse(subgrps=="[X1+ X2+]", 1, 0)+
+          0.45*ifelse(subgrps=="[X1+ X2-]", 1, 0)+
+          0.25*ifelse(subgrps=="[X1- X2+]", 1, 0) )
+    }
+    if (null){
+      trt.effect = 0
+    }
     ## Mean Function ##
-    mu.e = with(X, 1.5 +   A*( 0.65*ifelse(subgrps=="[X1+ X2+]", 1, 0)+
-                                 0.45*ifelse(subgrps=="[X1+ X2-]", 1, 0)+
-                                 0.25*ifelse(subgrps=="[X1- X2+]", 1, 0) )+
+    mu.e = with(X, 1.5 + trt.effect +
                   0.15*(X1-mean(X1))/sd(X1) + 0.20*(X2-mean(X2) )/sd(X2) +
                   0.10*(X3-mean(X3))/sd(X3)+
                   0.10*(X5-mean(X5) ) / sd(X5)  + 0.10*(X7-mean(X7))/ sd(X7) )
